Learn R Programming

mirt (version 0.1-17)

confmirt.model: Specify confirmatory loadings

Description

The confmirt.model function scans user input to specify the confirmatory model.

Usage

confmirt.model(file = '')

Arguments

file
a string specifying an external file that declares the input.

Value

  • Returns a model specification object to be used in confmirt.

Details

Factors are named and specify which numerical items they affect, seperated either by commas or by - to indicate a range of items. Six optional keyword to specify relationships between factors or by specifying constraints on the model. Note that all independent terms must be seperated with a comma. These are: [object Object],[object Object],[object Object],[object Object],[object Object],[object Object]

Examples

Run this code
model <- confmirt.model()
  F1 = 1,2,3,4-10
  F2 = 10-20
  COV = F1*F2
  PARTCOMP = 10
  SLOPE = F1@1 eq F1@2   
  MEAN = F1 eq 1, F2 eq -1          
  INT = 1@1 eq -0.5
  PRIOR = N(0,4)@1

Run the code above in your browser using DataLab