Learn R Programming

mirt (version 1.9)

PLCI.mirt: Compute profiled-likelihood confidence intervals

Description

Computes profiled-likelihood based confidence intervals. Supports the inclusion of prior parameter distributions as well as equality constraints. Object returns the confidence intervals and whether the respective interval could be found.

Usage

PLCI.mirt(mod, alpha = 0.05, parnum = NULL, plot = FALSE, npts = 24,
  ...)

Arguments

mod
a converged mirt model
alpha
two-tailed alpha critical level
parnum
a numeric vector indicating which parameters to estimate. Use mod2values to determine parameter numbers. If NULL, all possible parameters are used
plot
logical; plot the parameter relationship in the likelihood space for two parameters?
npts
number of points to evaluate and plot if plot = TRUE
...
additional arguments to pass to the estimation functions

See Also

boot.mirt

Examples

Run this code
mirtCluster() #use all available cores to estimate CI's in parallel
dat <- expand.table(LSAT7)
mod <- mirt(dat, 1)

result <- PLCI.mirt(mod)
result

mod2 <- mirt(Science, 1)
result2 <- PLCI.mirt(mod2)
result2

#only estimate CI's slopes
sv <- mod2values(mod2)
parnum <- sv$parnum[sv$name == 'a1']
result3 <- PLCI.mirt(mod2, parnum=parnum)
result3

# plot the confidence envelope for parameters 1 and 2
PLCI.mirt(mod2, parnum=c(1,2), plot=TRUE)

Run the code above in your browser using DataLab