The confmirt.model function scans user input to specify the confirmatory model.
Usage
confmirt.model(file = '')
Arguments
file
a string specifying an external file that declares the input.
Value
Returns a model specification object to be used in confmirt.
Details
Factors are named and specify which numerical items they affect, seperated either by commas or by - to indicate a range of items. Six optional keyword to specify relationships between factors or by specifying constraints on the model. Note that all independent terms must be seperated with a comma. These are:
[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]