mirt and bfactor models, or stocastic approximations for polymirt and confmirt. Note that only the general factor scores are computed for bifactor models.fscores(object, ...)
## S3 method for class 'mirt':
fscores(object, full.scores = FALSE,
method = "EAP", ...)
## S3 method for class 'bfactor':
fscores(object, full.scores = FALSE,
method = "EAP", ...)
## S3 method for class 'polymirt':
fscores(object, full.scores = FALSE,
ndraws = 3000, thin = 5, ...)
## S3 method for class 'confmirt':
fscores(object, full.scores = FALSE,
ndraws = 3000, thin = 5, ...)mirtClass or bfactorClassFALSE (default) then a summary table with factor scores for each unique pattern is displayed. Otherwise the original data matrix is returned with the computed factor scores appended to the rightmost column"EAP") or Bayes modal ("MAP")ndraws/thin must be a whole numbertabscores <- fscores(mod)
fullscores <- fscores(mod, full.scores = TRUE)Run the code above in your browser using DataLab